pub struct DownsampleDepthPipelines {
pub first: DownsampleDepthPipeline,
pub second: DownsampleDepthPipeline,
pub first_multisample: DownsampleDepthPipeline,
pub second_multisample: DownsampleDepthPipeline,
pub sampler: Sampler,
}Expand description
Stores all depth buffer downsampling pipelines.
Fields
first: DownsampleDepthPipelineThe first pass of the pipeline, when the depth buffer is not multisampled.
second: DownsampleDepthPipelineThe second pass of the pipeline, when the depth buffer is not multisampled.
first_multisample: DownsampleDepthPipelineThe first pass of the pipeline, when the depth buffer is multisampled.
second_multisample: DownsampleDepthPipelineThe second pass of the pipeline, when the depth buffer is multisampled.
sampler: SamplerThe sampler that the depth downsampling shader uses to sample the depth buffer.